EnhancedCodeGenerator class

Enhanced code generator with platform support and additional features.

Constructors

EnhancedCodeGenerator(ConfidentialConfiguration config, BuilderOptions options)

Properties

config → ConfidentialConfiguration
finalinherited
hashCode int
The hash code for this object.
no setterinherited
options → BuilderOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() String
Generates the complete Dart source code.
inherited
generateWithPlatformSupport(ConfidentialPlatform platform) Future<String>
Generates code with platform-specific optimizations and warnings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited